mocksey
=======

Stupidly-simple python mocking utility with moxie.

|BuildImage|_

.. image:: https://pypip.in/v/mocksey/badge.png
    :target: https://crate.io/packages/mocksey/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/mocksey/badge.png
    :target: https://crate.io/packages/mocksey/
    :alt: Number of PyPI downloads


Mocksey Motivation
==================

I was teaching a class on unit testing to a group of co-workers who were familiar with `Simple Test for PHP <http://www.simpletest.org/>`_ so I hacked together what is becoming Mocksey.

Mocksey the TDD'd version of that TDD utilty. `It's so meta even this acronym <http://xkcd.com/917/>`_.

Installation
============

Either find mocksey on PyPI_ or install it with pip or easy_install
::

  pip install mocksey
  #or
  easy_install mocksey

Basic Usage
===========

It's pretty simple.  Create a mocked object with generate_mock, inject it (or monkey patch) and set up your assertions.  After your function call(s), simply call 'run_asserts' and win!

The unit tests are a pretty decent working example.


License
=======
This software is hereby released under the MIT License, as seen in the LICENSE file

.. |BuildImage| image:: https://secure.travis-ci.org/mitgr81/mocksey.png
.. _BuildImage: https://travis-ci.org/mitgr81/mocksey
.. _PyPI: http://pypi.python.org/pypi/mocksey
